# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.1

import winrt.system
from winrt import _winrt_windows_media_ocr

__all__ = [
    "OcrEngine",
    "OcrLine",
    "OcrResult",
    "OcrWord",
]

OcrEngine = _winrt_windows_media_ocr.OcrEngine
OcrLine = _winrt_windows_media_ocr.OcrLine
OcrResult = _winrt_windows_media_ocr.OcrResult
OcrWord = _winrt_windows_media_ocr.OcrWord
